package Org::To::HTML::Link::cpanmod;

our $DATE = '2015-08-18'; # DATE
our $VERSION = '0.15'; # VERSION

1;
# ABSTRACT: cpanmod

__END__

=pod

=encoding UTF-8

=head1 NAME

Org::To::HTML::Link::cpanmod - cpanmod

=head1 VERSION

This document describes version 0.15 of Org::To::HTML::Link::cpanmod (from Perl distribution Org-To-HTML), released on 2015-08-18.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Org-To-HTML>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Org-To-HTML>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Org-To-HTML>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
